@@ -1,3 +1,3 @@
 d_voidsig=define
-d_novfork=undef
+d_vfork=undef
 d_sigblock=undef
